# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from knack.help_files import helps

helps['consumption'] = """
    type: group
    short-summary: Manage consumption of Azure resources.
"""

helps['consumption reservation'] = """
    type: group
    short-summary: Manage reservations for Azure resources.
"""

helps['consumption reservation summary'] = """
    type: group
    short-summary: List reservation summaries.
"""
helps['consumption reservation summary list'] = """
    type: command
    short-summary: List reservation summaries for daily or monthly by order Id or reservation id.
"""

helps['consumption reservation detail'] = """
    type: group
    short-summary: List reservation details.
"""

helps['consumption reservation detail list'] = """
    type: command
    short-summary: List the details of a reservation by order id or reservation id.
"""

helps['consumption usage'] = """
    type: group
    short-summary: Inspect the usage of Azure resources.
"""

helps['consumption usage list'] = """
    type: command
    short-summary: List the details of Azure resource consumption, either as an invoice or within a billing period.
"""

helps['consumption pricesheet'] = """
    type: group
    short-summary: Inspect the price sheet of an Azure subscription within a billing period.
"""

helps['consumption pricesheet show'] = """
    type: command
    short-summary: Show the price sheet for an Azure subscription within a billing period.
"""

helps['consumption marketplace'] = """
    type: group
    short-summary: Inspect the marketplace usage data of an Azure subscription within a billing period.
"""

helps['consumption marketplace list'] = """
    type: command
    short-summary: List the marketplace for an Azure subscription within a billing period.
"""

helps['consumption budget'] = """
    type: group
    short-summary: Manage budgets for an Azure subscription.
"""

helps['consumption budget list'] = """
    type: command
    short-summary: List budgets for an Azure subscription.
"""

helps['consumption budget show'] = """
    type: command
    short-summary: Show budget for an Azure subscription.
"""

helps['consumption budget create'] = """
    type: command
    short-summary: Create a budget for an Azure subscription.
"""

helps['consumption budget delete'] = """
    type: command
    short-summary: Delete a budget for an Azure subscription.
"""



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------


def transform_usage_output(result):
    result.usage_start = result.usage_start.strftime("%Y-%m-%dT%H:%M:%SZ")
    result.usage_end = result.usage_end.strftime("%Y-%m-%dT%H:%M:%SZ")
    result.usage_quantity = str(result.usage_quantity)
    result.billable_quantity = str(result.billable_quantity)
    result.pretax_cost = str(result.pretax_cost)
    if result.meter_details:
        result.meter_details.total_included_quantity = str(result.meter_details.total_included_quantity)
        result.meter_details.pretax_standard_rate = str(result.meter_details.pretax_standard_rate)
    return result


def transform_usage_list_output(result):
    return [transform_usage_output(item) for item in result]


def reservation_summary_output(result):

    result.reserved_hours = str(result.reserved_hours)
    result.usage_date = result.usage_date.strftime("%Y-%m-%dT%H:%M:%SZ")
    result.used_hours = str(result.used_hours)
    result.max_utilization_percentage = str(result.max_utilization_percentage)
    result.min_utilization_percentage = str(result.min_utilization_percentage)
    result.avg_utilization_percentage = str(result.avg_utilization_percentage)
    return result


def transform_reservation_summary_list_output(result):
    return [reservation_summary_output(item) for item in result]


def reservation_detail_output(result):

    result.reserved_hours = str(result.reserved_hours)
    result.usage_date = result.usage_date.strftime("%Y-%m-%dT%H:%M:%SZ")
    result.used_hours = str(result.used_hours)
    result.total_reserved_quantity = str(result.total_reserved_quantity)
    return result


def transform_reservation_detail_list_output(result):
    return [reservation_detail_output(item) for item in result]


def pricesheet_show_properties(result):
    result.unit_of_measure = str(result.unit_of_measure)
    result.included_quantity = str(result.included_quantity)
    result.unit_price = str(result.unit_price)
    if result.meter_details:
        result.meter_details.total_included_quantity = str(result.meter_details.total_included_quantity)
        result.meter_details.pretax_standard_rate = str(result.meter_details.pretax_standard_rate)
    return result


def transform_pricesheet_show_output(result):
    result.pricesheets = [pricesheet_show_properties(item) for item in result.pricesheets]
    return result


def marketplace_list_output(result):
    result.pretax_cost = str(result.pretax_cost)
    result.consumed_quantity = str(result.consumed_quantity)
    result.resource_rate = str(result.resource_rate)
    return result


def transform_marketplace_list_output(result):
    return [marketplace_list_output(item) for item in result]


def budget_output(result):
    result.amount = str(result.amount)
    if result.current_spend:
        result.current_spend.amount = str(result.current_spend.amount)
    return result


def transform_budget_list_output(result):
    return [budget_output(item) for item in result]


def transform_budget_show_output(result):
    return budget_output(result)


def transform_budget_create_update_output(result):
    return budget_output(result)
